@@ -2,11 +2,13 @@
 use strict;
 use warnings;
 
-BEGIN {
-	push @INC, 'lib';
+BEGIN { 
+    unshift @INC, 'lib';
+    #chdir 'base';
 }
 
-use Kephra;
+require Kephra;
+
 $Kephra::STANDALONE = 'dev';
 Kephra->new->MainLoop;
 
@@ -16,5 +18,3 @@ Kephra->new->MainLoop;
 #my $lib = catfile( $FindBin::Bin, 'lib' );
 #my $exe = catfile( $FindBin::Bin, 'bin', 'kephra' );
 #system "$^X @ARGV -I$lib $exe";
-
-
