@@ -1,27 +1,30 @@
 package Kephra::App::MainToolBar;
+our $VERSION = '0.08';
+
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
 
-
-sub _ref { Kephra::App::ToolBar::_ref('main', $_[0]) }
-sub _config{ $Kephra::config{app}{toolbar}{main} }
+sub _ref    { Kephra::App::ToolBar::_ref( _name(), $_[0]) }
+sub _name   { 'main' }
+sub _ID     { _name().'_toolbar' }
+sub _config { $Kephra::config{app}{toolbar}{main} }
 
 sub create {
 	return until get_visibility();
 	my $frame = Kephra::App::Window::_ref();
 	my $bar = $frame->GetToolBar;
-	$bar->Destroy if $bar;          # destroy old toolbar if there any
+	# destroy old toolbar if there any
+	Kephra::App::ToolBar::destroy( _name() ) if $bar;
 	_ref( $frame->CreateToolBar );
 	my $bar_def = Kephra::Config::File::load_from_node_data( _config() );
 	unless ($bar_def) {
 		$bar_def = Kephra::Config::Tree::get_subtree
-			( Kephra::Config::Default::toolbars(), 'main_toolbar');
+			( Kephra::Config::Default::toolbars(), _ID() );
 	}
-	Kephra::App::ToolBar::create( 'main', $bar_def );
+	Kephra::App::ToolBar::create( _name(), $bar_def );
 }
-sub destroy { Kephra::App::ToolBar::destroy ('main') }
+sub destroy { Kephra::App::ToolBar::destroy ( _name() ) }
 
 sub get_visibility    { _config()->{visible} }
 sub switch_visibility { _config()->{visible} ^= 1; show(); }
@@ -29,7 +32,7 @@ sub show {
 	if ( get_visibility() ){
 		create()
 	} else {
-		_ref()->Destroy;
+		Kephra::App::ToolBar::destroy( _name() );
 		Kephra::App::Window::_ref()->SetToolBar(undef);
 	}
 }
