@@ -2,7 +2,7 @@ package Kephra::App::Menu;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =item1 Name
 
@@ -310,4 +310,12 @@ sub eval_data {
 	return $menu;
 }
 
+sub destroy {
+	my $menu_ID = shift;
+	my $menu = _ref( $menu_ID );
+	return unless $menu;
+	$menu->Destroy;
+	Kephra::API::EventTable::del_own_subscription( $menu_ID );
+}
+
 1;
