@@ -76,15 +76,12 @@ sub _delete_data {
 # API
 #
 sub define_marker {
-	my $conf       = $Kephra::config{editpanel}{margin}{marker};
-	my $color      = \&Kephra::Config::color;
-	my $foreground = &$color( $conf->{fore_color} );
-	my $background = &$color( $conf->{back_color} );
-	my $edit_panel = Kephra::App::EditPanel::_ref();
-	for my $i ( 0 .. 9 ) {
-		$edit_panel->MarkerDefine
-			( $i, wxSTC_MARK_SHORTARROW, $foreground, $background )
-	}
+	my $conf = $Kephra::config{editpanel}{margin}{marker};
+	my $color= \&Kephra::Config::color;
+	my $fore = &$color( $conf->{fore_color} );
+	my $back = &$color( $conf->{back_color} );
+	my $ep = Kephra::App::EditPanel::_ref();
+	$ep->MarkerDefine( $_, wxSTC_MARK_SHORTARROW, $fore, $back ) for 0 .. 9;
 }
 
 sub restore_all {
@@ -108,6 +105,16 @@ sub restore_all {
 
 sub save_all { _refresh_data_nr($_) for 0..9 }
 
+sub toggle_nr_0 { toggle_nr( 0 ) }
+sub toggle_nr_1 { toggle_nr( 1 ) }
+sub toggle_nr_2 { toggle_nr( 2 ) }
+sub toggle_nr_3 { toggle_nr( 3 ) }
+sub toggle_nr_4 { toggle_nr( 4 ) }
+sub toggle_nr_5 { toggle_nr( 5 ) }
+sub toggle_nr_6 { toggle_nr( 6 ) }
+sub toggle_nr_7 { toggle_nr( 7 ) }
+sub toggle_nr_8 { toggle_nr( 8 ) }
+sub toggle_nr_9 { toggle_nr( 9 ) }
 sub toggle_nr {
 	my $nr = shift;
 	my $edit_panel = Kephra::App::EditPanel::_ref();
@@ -131,25 +138,6 @@ sub toggle_nr {
 	} else { $edit_panel->GotoPos($pos) }
 }
 
-sub toggle_nr_0 { toggle_nr( 0 ) }
-sub toggle_nr_1 { toggle_nr( 1 ) }
-sub toggle_nr_2 { toggle_nr( 2 ) }
-sub toggle_nr_3 { toggle_nr( 3 ) }
-sub toggle_nr_4 { toggle_nr( 4 ) }
-sub toggle_nr_5 { toggle_nr( 5 ) }
-sub toggle_nr_6 { toggle_nr( 6 ) }
-sub toggle_nr_7 { toggle_nr( 7 ) }
-sub toggle_nr_8 { toggle_nr( 8 ) }
-sub toggle_nr_9 { toggle_nr( 9 ) }
-
-sub goto_nr {
-	my $nr = shift;
-	if ( _refresh_data_nr($nr) ) {
-		Kephra::Document::Change::to_number
-			( $Kephra::temp{search}{bookmark}{$nr}{doc_nr} );
-		Kephra::Edit::Goto::pos( $Kephra::config{search}{bookmark}{$nr}{pos} );
-	}
-}
 
 sub goto_nr_0 { goto_nr( 0 ) }
 sub goto_nr_1 { goto_nr( 1 ) }
@@ -161,7 +149,26 @@ sub goto_nr_6 { goto_nr( 6 ) }
 sub goto_nr_7 { goto_nr( 7 ) }
 sub goto_nr_8 { goto_nr( 8 ) }
 sub goto_nr_9 { goto_nr( 9 ) }
+sub goto_nr {
+	my $nr = shift;
+	if ( _refresh_data_nr($nr) ) {
+		Kephra::Document::Change::to_nr
+			( $Kephra::temp{search}{bookmark}{$nr}{doc_nr} );
+		Kephra::Edit::Goto::pos( $Kephra::config{search}{bookmark}{$nr}{pos} );
+	}
+}
 
+sub delete_nr {
+	my $nr = shift;
+	if ( _refresh_data_nr( $nr ) ){
+		my $cur_doc_nr = Kephra::Document::current_nr();
+		Kephra::Document::Internal::change_pointer
+			( $Kephra::temp{search}{bookmark}{$nr}{doc_nr} );
+		Kephra::App::EditPanel::_ref()->MarkerDeleteAll($nr);
+		_delete_data($nr);
+		Kephra::Document::Internal::change_pointer($cur_doc_nr);
+	}
+}
 sub delete_all {
 	Kephra::Edit::_save_positions();
 	delete_nr($_) for 0..9;
@@ -169,19 +176,4 @@ sub delete_all {
 	Wx::Window::SetFocus(Kephra::App::EditPanel::_ref());
 }
 
-sub delete_nr {
-	my $nr = shift;
-	if ( _refresh_data_nr( $nr ) ){
-		my $edit_panel = Kephra::App::EditPanel::_ref();
-		my $cur_doc_nr = Kephra::Document::current_nr();
-
-		Kephra::Document::Internal::change_pointer(
-			$Kephra::temp{search}{bookmark}{$nr}{doc_nr}
-		);
-		$edit_panel->MarkerDeleteAll($nr);
-		_delete_data($nr);
-		Kephra::Document::Internal::change_pointer($cur_doc_nr);
-	}
-}
-
 1;
